@@ -244,8 +244,8 @@ class ActivationAnalysis:
     def run_evaluators(self, evaluators, e_args):
         """Run a list of evaluators on our ROIs, with arguments specified in the list e_args"""
         ROIsToEval = [r for r in self.ROIs if r.fitted]
-        successfulROIs = []
         for i in range(len(self.fileData)):
+            successfulROIs = []
             if i != 0:
                 energies = self.fileData[i]["energies"]
                 cps = self.fileData[i]["cps"]
@@ -261,6 +261,8 @@ class ActivationAnalysis:
                         successfulROIs.append(r)
                     except Exception:
                         continue
+            else:
+                successfulROIs = ROIsToEval
             self.fileData[i]["results"] = [e(successfulROIs).get_results(*args) for e, args in zip(evaluators, e_args)]
             self.fileData[i]["resultHeadings"] = [e.get_headings(ROIsToEval[0]) for e in evaluators]
             self.fileData[i]["evaluatorNames"] = [e.get_name() for e in evaluators]
